==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/DifferentAccessPaths.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.query;

namespace com.db4o.test
{
	public class DifferentAccessPaths
	{
        String foo;

        public void store(){
            Tester.deleteAllInstances(this);
            DifferentAccessPaths dap = new DifferentAccessPaths();
            dap.foo = "hi";
            Tester.store(dap);
            dap = new DifferentAccessPaths();
            dap.foo = "hi too";
            Tester.store(dap);
        }

        public void test(){
            DifferentAccessPaths dap = query();
            for(int i = 0; i < 10; i ++){
                Tester.ensure(dap == query());
            }
            Tester.objectContainer().purge(dap);
            Tester.ensure(dap != query());
        }

        private DifferentAccessPaths query(){
            Query q = Tester.query();
            q.constrain(typeof(DifferentAccessPaths));
            q.descend("foo").constrain("hi");
            ObjectSet os = q.execute();
            DifferentAccessPaths dap = (DifferentAccessPaths)os.next();
            return dap;
        }

	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/DifferentAccessPaths.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.query;

namespace com.db4o.test
{
	public class DifferentAccessPaths
	{
        String foo;

        public void Store(){
            Tester.DeleteAllInstances(this);
            DifferentAccessPaths dap = new DifferentAccessPaths();
            dap.foo = "hi";
            Tester.Store(dap);
            dap = new DifferentAccessPaths();
            dap.foo = "hi too";
            Tester.Store(dap);
        }

        public void Test(){
            DifferentAccessPaths dap = Query();
            for(int i = 0; i < 10; i ++){
                Tester.Ensure(dap == Query());
            }
            Tester.ObjectContainer().Purge(dap);
            Tester.Ensure(dap != Query());
        }

        private DifferentAccessPaths Query(){
            Query q = Tester.Query();
            q.Constrain(typeof(DifferentAccessPaths));
            q.Descend("foo").Constrain("hi");
            ObjectSet os = q.Execute();
            DifferentAccessPaths dap = (DifferentAccessPaths)os.Next();
            return dap;
        }

	}
}
